==> deepin-update-ui_1.0.6.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Restaurando el sistema, por favor espere...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>La restauración falló.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Actualización fallida.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Actualizacion fallida: se interrumpió.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Actualizaciones fallidas: error DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>La actualización falló: espacio de disco insuficiente.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>¿Está seguro de que desea revertir a %1 respaldado en %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancelar y reiniciar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Aceptar</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Restaurando el sistema, por favor espere...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>La restauración falló.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>La actualización falló.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>La actualizacion falló: se interrumpió.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>La actualización falló: error DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>La actualización falló: espacio de disco insuficiente.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>¿Está seguro de que desea revertir a %1 respaldado en %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Cancelar y reiniciar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Aceptar</translation>
    </message>
</context>
</TS>
